_`umbra.ui.inputAccelerators`
=============================

.. automodule:: umbra.ui.inputAccelerators

Module Attributes
-----------------

.. attribute:: umbra.ui.inputAccelerators.LOGGER

Functions
---------

.. autofunction:: getEditorCapability

.. autofunction:: indentationPreEventInputAccelerators

.. autofunction:: indentationPostEventInputAccelerators

.. autofunction:: performCompletion

.. autofunction:: completionPreEventInputAccelerators

.. autofunction:: completionPostEventInputAccelerators

.. autofunction:: symbolsExpandingPreEventInputAccelerators

